﻿using UnityEngine;
using System.Collections;

public class GunnerController : MonoBehaviour
{
    public GameObject shot;
    public Transform shotSpawn;
    public float fireRate = 0.25f;
    public bool restrainAngle; //use a restrained angle

    private float nextFire;
    private Vector3 mousePos;
    private Vector3 objectPos;
    private float angle;

    void Update()
    {
        //determine mouse position
        mousePos = Input.mousePosition;
        objectPos = Camera.main.WorldToScreenPoint(shotSpawn.position);
        mousePos.x = mousePos.x - objectPos.x;
        mousePos.y = mousePos.y - objectPos.y;

        //restrain angle
        angle = Mathf.Atan2(mousePos.x, mousePos.y) * Mathf.Rad2Deg;
        if (restrainAngle)
        {
            angle = RestrainAngle(angle);
        }
        
        //shoot bullet
        shotSpawn.transform.rotation = Quaternion.Euler(new Vector3(0, angle, 0));

        //restrain fire rate
        if (Input.GetButton("Fire1") && Time.time > nextFire)
        {
            nextFire = Time.time + fireRate;
            Instantiate(shot, shotSpawn.position, shotSpawn.rotation);
            gameObject.GetComponent<AudioSource>().Play();
        }
    }

    /*
     * Restrains the shooting angle of the gunner of the gunner by correcting
     * the angle if it exceeds the limits.
     * It is only possible to shoot from the angles 45 to 135 and -45 to -135
     */
    public float RestrainAngle(float angle)
    {
        float restrainedAngle = angle;
        if (angle >= 0 && angle < 45)
        {
            restrainedAngle = 45;
        }
        else if (angle > 135 && angle <= 180)
        {
            restrainedAngle = 135;
        }
        else if (angle < -0 && angle >= -45)
        {
            restrainedAngle = -45;
        }
        else if (angle < -135 && angle >= -180)
        {
            restrainedAngle = -135;
        }
        return restrainedAngle;
    }
}
